@@ -3,9 +3,10 @@ The form module contains the main form, field, group and sequence classes
 """
 
 import re
+import warnings
 
 from peak.util.proxies import ObjectWrapper
-from webob import UnicodeMultiDict
+from webob.multidict import UnicodeMultiDict
 
 import schemaish, validatish
 from formish import util
@@ -110,7 +111,7 @@ def fall_back_renderer(renderer, name, widget, vars):
     import mako
     try:
         return renderer('/formish/widgets/%s/%s.html'%(widget,name), vars)
-    except mako.exceptions.TopLevelLookupException, e:
+    except mako.exceptions.TopLevelLookupException:
         return renderer('/formish/%s.html'%(name), vars)
     
 
@@ -148,6 +149,58 @@ class TemplatedString(object):
         return fall_back_renderer(renderer, name, widget, vars)
 
 
+class RenderableProperty(object):
+    """
+    Property descriptor that returns a renderable proxy when retrieved from the
+    the property's instance.
+    """
+
+    def __init__(self, property_name, getter, setter=None, deleter=None):
+        self.property_name = property_name
+        self.getter = getter
+        self.setter = setter
+        self.deleter = deleter
+
+    def __get__(self, instance, owner):
+        return RenderableObjectWrapper(self.getter(instance), instance,
+                                       self.property_name)
+
+    def __set__(self, instance, value):
+        self.setter(instance, value)
+
+    def __delete__(self, instance):
+        self.deleter(instance)
+
+
+class RenderableObjectWrapper(ObjectWrapper):
+    """
+    Proxy object that, when called, renders itself using a template. The name
+    of the template is derived from the form item and the name of the property.
+    """
+
+    # Non-proxied attributes.
+    __form_item = None
+    __property_name = None
+
+    def __init__(self, obj, form_item, property_name):
+        ObjectWrapper.__init__(self, obj)
+        self.__form_item = form_item
+        self.__property_name = property_name
+
+    def __call__(self):
+        # XXX This is a hack to make it work for a Form property. A Form
+        # doesn't look enough like any other form item right now to work
+        # otherwise.
+        if isinstance(self.__form_item, Form):
+            return self.__form_item.renderer(
+                '/formish/form/%s.html' % self.__property_name,
+                {'form': self.__form_item})
+        # So, we're a field (doesn't seem to support container form items yet).
+        widget_type, widget = self.__form_item.widget.template.split('.')
+        name = '%s/%s'%(widget_type,self.__property_name)
+        vars = {'field':self.__form_item}
+        return fall_back_renderer(self.__form_item.form.renderer, name, widget, vars)
+
 
 class Field(object):
     """
@@ -189,16 +242,14 @@ class Field(object):
             else:
                 return util.title_from_name(self.name.split('.')[-1])
 
-
-    @property
-    def description(self):
-        """ The Field schema's description """
-        try:
-            val =  self.form.get_item_data(self.name,'description')
-        except KeyError:
-            val = self.attr.description        
-        return TemplatedString(self, 'description', val)
-
+    def description():
+        def get(self):
+            try:
+                return self.form.get_item_data(self.name, 'description')
+            except KeyError:
+                return self.attr.description        
+        return RenderableProperty('description', get)
+    description = description()
 
     @property
     def cssname(self):
@@ -399,11 +450,11 @@ class Collection(object):
         return name
 
 
-    @property
-    def description(self):
-        """ Returns the schema's description """
-        val = self.attr.description        
-        return TemplatedString(self,'description',val)
+    def description():
+        def get(self):
+            return self.attr.description
+        return RenderableProperty('description', get)
+    description = description()
 
 
     @property
@@ -771,10 +822,11 @@ class ErrorDict(dict):
     def __iter__(self):
         for field in self.form.allfields:
             if field.name in self:
-                yield self[field.name]
-                if isinstance(basedict, self[field.name]):
+                fieldvalue = self[field.name]
+                yield fieldvalue
+                if isinstance(fieldvalue, dict):
                     keys = []
-                    for k in self[field.name].keys():
+                    for k in fieldvalue.keys():
                         keys.append( [tryint(k) for k in k.split('.')] )
                     keys.sort()
                     for k in keys:
@@ -800,10 +852,12 @@ class Form(object):
 
     _request_data = None
 
+    base_classes = ['formish-form']
+
     def __init__(self, structure, name=None, defaults=None, errors=None,
                  action_url=None, renderer=None, method='post',
                  add_default_action=True, include_charset=True,
-                 empty=UNSET):
+                 empty=UNSET, error_summary=None,error_summary_message=None,classes=None):
         """
         Create a new form instance
 
@@ -827,6 +881,9 @@ class Form(object):
 
         :arg method: Option method, default POST
         :type method: string
+
+        :arg error_summary: None, 'message', 'list'
+        :type error_summary: string
         """
         if method.lower() not in self.SUPPORTED_METHODS:
             raise ValueError("method must be one of GET or POST")
@@ -842,8 +899,17 @@ class Form(object):
             errors = ErrorDict(self)
         self.defaults = defaults
         self.errors = errors
-        self.error = None
+        self._alert = None
+        self.error_summary = error_summary
+        self.error_summary_message = error_summary_message
         self._actions = []
+        if classes is not None:
+            if isinstance(classes, basestring):
+                self.classes = self.base_classes + [classes]
+            else:
+                self.classes = self.base_classes + classes
+        else:
+            self.classes = self.base_classes
         if add_default_action:
             self.add_action( None, 'Submit' )
         self.action_url = action_url
@@ -855,6 +921,31 @@ class Form(object):
         if empty is not UNSET:
             self.empty = empty
 
+    def alert():
+        def get(self):
+            return self._alert
+        def set(self, alert):
+            self._alert = alert
+        return RenderableProperty('alert', get, set)
+    alert = alert()
+
+    @staticmethod
+    def _error_warning():
+        warnings.warn("Form.error has been deprecated and will change behaviour "
+                      "in the future. Please use Form.alert to display a general "
+                      "form error message.",
+                      DeprecationWarning, stacklevel=3)
+
+    def _set_error(self, error):
+        self._error_warning()
+        self.alert = error
+
+    def _get_error(self, error):
+        self._error_warning()
+        return self.alert
+
+    error = property(_get_error, _set_error)
+
     def __repr__(self):
         attributes = []
         attributes.append('%r'%self.structure.attr)
@@ -1014,7 +1105,7 @@ class Form(object):
             raise Exception("request does not match form name")
         try: 
             data = self._validate(request, skip_read_only_defaults=skip_read_only_defaults)
-        except validation.FormError, e:
+        except validation.FormError:
             if failure_callable is None:
                 raise
             else:
