@@ -165,11 +165,13 @@ class CheckedPassword(Input):
 
     type = 'CheckedPassword'
     template = 'field.CheckedPassword'
+    confirm_label = None
     default_value = {'password': [''], 'confirm': ['']}
 
     def __init__(self, **k):
         self.strip = k.pop('strip', True)
         self.css_class = k.pop('css_class', None)
+        self.confirm_label = k.pop('confirm_label',None)
         Input.__init__(self, **k)
         if not self.converter_options.has_key('delimiter'):
             self.empty.converter_options['delimiter'] = ','
@@ -219,11 +221,13 @@ class CheckedInput(Input):
 
     type = 'CheckedInput'
     template = 'field.CheckedInput'
+    confirm_label = None
     default_value = {'input': [''], 'confirm': ['']}
 
     def __init__(self, **k):
         self.strip = k.pop('strip', True)
         self.css_class = k.pop('css_class', None)
+        self.confirm_label = k.pop('confirm_label',None)
         Input.__init__(self, **k)
         if not self.converter_options.has_key('delimiter'):
             self.converter_options['delimiter'] = ','
@@ -355,7 +359,7 @@ class SequenceDefault(Container):
         for f in field.fields:
             try:
                 r = request_data[int(f.nodename)]
-            except TypeError, KeyError:
+            except (TypeError, KeyError):
                 r = None
             d = f.widget.pre_parse_incoming_request_data(f, r)
             data[f.nodename] = d
@@ -1012,7 +1016,6 @@ def get_parent(segments):
         return '.'.join(segments[:-1])
 
 def mktree(options):
-    last_segments_len = 1
     root = {'': {'data':('root', 'Root'), 'children':[]} }
     for id, label in options:
         segments = id.split('.')
